@@ -89,7 +89,9 @@ static void detectQualcomm(FFCPUResult* cpu)
 {
     // https://en.wikipedia.org/wiki/List_of_Qualcomm_Snapdragon_systems_on_chips
 
-    if (ffStrbufEqualS(&cpu->name, "SM8635"))
+    if (ffStrbufEqualS(&cpu->name, "SM8750"))
+        ffStrbufSetStatic(&cpu->name, "Qualcomm Snapdragon 8 Elite [SM8750]");
+    else if (ffStrbufEqualS(&cpu->name, "SM8635"))
         ffStrbufSetStatic(&cpu->name, "Qualcomm Snapdragon 8s Gen 3 [SM8635]");
     else if (ffStrbufEqualS(&cpu->name, "SM8650-AC"))
         ffStrbufSetStatic(&cpu->name, "Qualcomm Snapdragon 8 Gen 3 for Galaxy [SM8650-AC]");
@@ -389,7 +391,7 @@ FF_MAYBE_UNUSED static void detectArmSoc(FFCPUResult* cpu)
 
     // device-vendor,device-model\0soc-vendor,soc-model\0
     char content[256];
-    ssize_t length = ffReadFileData("/proc/device-tree/compatible", sizeof(content), content);
+    ssize_t length = ffReadFileData("/proc/device-tree/compatible", ARRAY_SIZE(content), content);
     if (length <= 2) return;
 
     // get the second NUL terminated string if it exists
