@@ -244,13 +244,19 @@ static void detectFootTerminal(FFTerminalFontResult* terminalFont)
         return;
     }
     uint32_t equal = ffStrbufNextIndexS(&font, colon, "size=");
-    font.chars[colon] = 0;
+    font.chars[colon] = '\0';
     if (equal == font.length)
     {
         ffFontInitValues(&terminalFont->font, font.chars, "8");
         return;
     }
-    ffFontInitValues(&terminalFont->font, font.chars, &font.chars[equal + strlen("size=")]);
+    uint32_t size = equal + strlen("size=");
+    uint32_t comma = ffStrbufNextIndexC(&font, size, ',');
+    if (comma < font.length)
+        font.chars[comma] = '\0';
+    ffFontInitValues(&terminalFont->font, font.chars, &font.chars[size]);
+    if (comma < font.length)
+        ffFontInitValues(&terminalFont->fallback, &font.chars[comma + 1], NULL);
 }
 
 static void detectQTerminal(FFTerminalFontResult* terminalFont)
@@ -287,10 +293,10 @@ static void detectXterm(FFTerminalFontResult* terminalFont)
     ffFontInitValues(&terminalFont->font, fontName.chars, fontSize.chars);
 }
 
-static bool elfExtractStringsCallBack(const char* str, uint32_t len, void* userData)
+static bool extractStTermFont(const char* str, FF_MAYBE_UNUSED uint32_t len, void* userdata)
 {
     if (!ffStrContains(str, "size=")) return true;
-    ffStrbufSetNS((FFstrbuf*) userData, len, str);
+    ffStrbufSetNS((FFstrbuf*) userdata, len, str);
     return false;
 }
 
@@ -315,7 +321,7 @@ static void detectSt(FFTerminalFontResult* terminalFont, const FFTerminalResult*
     {
         ffStrbufClear(&font);
 
-        const char* error = ffBinaryExtractStrings(terminal->exePath.chars, elfExtractStringsCallBack, &font);
+        const char* error = ffBinaryExtractStrings(terminal->exePath.chars, extractStTermFont, &font, (uint32_t) strlen("size=0"));
         if (error)
         {
             ffStrbufAppendS(&terminalFont->error, error);
