@@ -6,9 +6,7 @@
 
 void ffPrintCustom(FFCustomOptions* options)
 {
-    ffPrintLogoAndKey(FF_CUSTOM_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT);
-    ffStrbufWriteTo(&options->moduleArgs.outputFormat, stdout);
-    puts(FASTFETCH_TEXT_MODIFIER_RESET);
+    ffPrintFormat(FF_CUSTOM_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, 0, ((FFformatarg[]) {}));
 }
 
 bool ffParseCustomCommandOptions(FFCustomOptions* options, const char* key, const char* value)
@@ -59,7 +57,7 @@ void ffInitCustomOptions(FFCustomOptions* options)
         NULL,
         ffGenerateCustomJsonConfig
     );
-    ffOptionInitModuleArg(&options->moduleArgs);
+    ffOptionInitModuleArg(&options->moduleArgs, "");
     ffStrbufSetStatic(&options->moduleArgs.key, " ");
 }
 
